@@ -16,11 +16,16 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
-#ifndef __LIB_KMAHJONGGTILESETSELECTOR_H_
-#define __LIB_KMAHJONGGTILESETSELECTOR_H_
+#ifndef KMAHJONGGTILESETSELECTOR_H
+#define KMAHJONGGTILESETSELECTOR_H
 
+// Qt
 #include <QMap>
+
+// KDE
 #include <KConfigSkeleton>
+
+// LibKMahjongg
 #include "ui_kmahjonggtilesetselector.h"
 
 class KMahjonggTileset;
@@ -29,13 +34,13 @@ class KMahjonggTilesetSelector : public QWidget, public Ui::KMahjonggTilesetSele
 {
 Q_OBJECT
   public:
-    explicit KMahjonggTilesetSelector( QWidget* parent, KConfigSkeleton * config );
+    explicit KMahjonggTilesetSelector( QWidget* parent, KConfigSkeleton * aconfig );
     ~KMahjonggTilesetSelector();
-    void setupData(KConfigSkeleton * config);
+    void setupData(KConfigSkeleton * aconfig);
 
     QMap<QString, KMahjonggTileset *> tilesetMap;
   public slots:
     void tilesetChanged();
 };
 
-#endif // __LIB_KMAHJONGGTILESETSELECTOR_H_
+#endif // KMAHJONGGTILESETSELECTOR_H
